pub struct SetMyDescription { /* private fields */ }Expand description
Builder for the setMyDescription method.
Implementations
Sourceimpl SetMyDescription
impl SetMyDescription
Sourcepub fn description(self, d: impl Into<String>) -> Self
pub fn description(self, d: impl Into<String>) -> Self
Sets the new bot description shown on the profile page (up to 512 characters).
Sourcepub fn language_code(self, lc: impl Into<String>) -> Self
pub fn language_code(self, lc: impl Into<String>) -> Self
Sets the language code for localised bot descriptions (IETF tag, e.g. "en").