SetBusinessAccountProfilePhoto

Struct SetBusinessAccountProfilePhoto 

pub struct SetBusinessAccountProfilePhoto { /* private fields */ }
Builder for the setBusinessAccountProfilePhoto method.

Changes the profile photo of a managed business account. Requires the can_edit_profile_photo business bot right.

Pass the photo as serde_json::to_value(&input_profile_photo).

Implementations

Source

impl SetBusinessAccountProfilePhoto

pub fn is_public(self, v: bool) -> Self

Pass true to set the public photo, visible even if the main photo is hidden by the account’s privacy settings. An account can have only one public photo.