BanChatSenderChat

Struct BanChatSenderChat 

pub struct BanChatSenderChat { /* private fields */ }
Builder for the banChatSenderChat method.

Bans a channel chat in a supergroup or channel. The owner of the banned chat will not be able to send messages on behalf of any of their channels until unbanned.