pub struct EditChatInviteLink { /* private fields */ }Expand description
Builder for the editChatInviteLink method.
Implementations
Sourceimpl EditChatInviteLink
impl EditChatInviteLink
Sourcepub fn name(self, n: impl Into<String>) -> Self
pub fn name(self, n: impl Into<String>) -> Self
Sets the name of the invite link (0–32 characters).
Sourcepub fn expire_date(self, ts: i64) -> Self
pub fn expire_date(self, ts: i64) -> Self
Sets the Unix timestamp when the invite link expires.
Sourcepub fn member_limit(self, n: u32) -> Self
pub fn member_limit(self, n: u32) -> Self
Limits how many users can join via this link (1–99999).
Sourcepub fn creates_join_request(self, v: bool) -> Self
pub fn creates_join_request(self, v: bool) -> Self
Makes the link require admin approval for each join request.