ApproveSuggestedPost

Struct ApproveSuggestedPost 

pub struct ApproveSuggestedPost { /* private fields */ }
Builder for the approveSuggestedPost method.

Approves a suggested post in a direct messages chat. Requires the can_post_messages administrator right in the corresponding channel.

Implementations

Source

impl ApproveSuggestedPost

pub fn send_date(self, ts: i64) -> Self

Unix timestamp when the post will be published (not more than 30 days in the future).

Omit if the send date was already specified when the post was suggested.