EditEphemeralMessageCaption

Struct EditEphemeralMessageCaption 

pub struct EditEphemeralMessageCaption { /* private fields */ }
Builder for the editEphemeralMessageCaption method.

Note that it is not guaranteed that the user will receive the message edit event, especially if they are offline.

Implementations

Source

impl EditEphemeralMessageCaption

pub fn caption(self, c: impl Into<String>) -> Self

Sets the new caption text (0–1024 characters).

pub fn parse_mode(self, m: ParseMode) -> Self

Sets the caption parse mode.

pub fn caption_entities(self, e: Vec<MessageEntity>) -> Self

Special entities in the caption, in place of parse_mode.

pub fn reply_markup(self, m: InlineKeyboardMarkup) -> Self

Attaches a reply markup (inline keyboard, reply keyboard, etc.).