pub struct EditEphemeralMessageMedia { /* private fields */ }Expand description
Builder for the editEphemeralMessageMedia method.
Note that it is not guaranteed that the user will receive the message edit event, especially if they are offline.
Implementations
Sourceimpl EditEphemeralMessageMedia
impl EditEphemeralMessageMedia
Sourcepub fn reply_markup(self, m: InlineKeyboardMarkup) -> Self
pub fn reply_markup(self, m: InlineKeyboardMarkup) -> Self
Attaches a reply markup (inline keyboard).