pub struct EditEphemeralMessageReplyMarkup { /* private fields */ }Expand description
Builder for the editEphemeralMessageReplyMarkup method.
Note that it is not guaranteed that the user will receive the message edit event, especially if they are offline.
Implementations
Sourceimpl EditEphemeralMessageReplyMarkup
impl EditEphemeralMessageReplyMarkup
Sourcepub fn reply_markup(self, m: InlineKeyboardMarkup) -> Self
pub fn reply_markup(self, m: InlineKeyboardMarkup) -> Self
Attaches a reply markup (inline keyboard, reply keyboard, etc.).
Sourcepub fn remove_markup(self) -> Self
pub fn remove_markup(self) -> Self
Removes the inline keyboard from the message.