EditEphemeralMessageText

Struct EditEphemeralMessageText 

pub struct EditEphemeralMessageText { /* private fields */ }
Builder for the editEphemeralMessageText method.

Note that it is not guaranteed that the user will receive the message edit event, especially if they are offline.

Implementations

Source

impl EditEphemeralMessageText

pub fn parse_mode(self, m: ParseMode) -> Self

Sets the parse mode for the message text.

pub fn entities(self, e: Vec<MessageEntity>) -> Self

Special entities in the message text, in place of parse_mode.

pub fn reply_markup(self, m: InlineKeyboardMarkup) -> Self

Attaches a reply markup (inline keyboard, reply keyboard, etc.).

Configures link preview generation options.