pub struct EditMessageCaption { /* private fields */ }Expand description
Builder for the editMessageCaption method.
Implementations
Sourceimpl EditMessageCaption
impl EditMessageCaption
Sourcepub fn caption(self, c: impl Into<String>) -> Self
pub fn caption(self, c: impl Into<String>) -> Self
Sets the new caption text (0–1024 characters).
Sourcepub fn parse_mode(self, m: ParseMode) -> Self
pub fn parse_mode(self, m: ParseMode) -> Self
Sets the caption parse mode (MarkdownV2, HTML, or Markdown).
Sourcepub fn show_caption_above_media(self, v: bool) -> Self
pub fn show_caption_above_media(self, v: bool) -> Self
Shows the caption above the media instead of below it.
Sourcepub fn reply_markup(self, m: InlineKeyboardMarkup) -> Self
pub fn reply_markup(self, m: InlineKeyboardMarkup) -> Self
Attaches a reply markup (inline keyboard, reply keyboard, etc.).
Sourcepub fn business_connection_id(self, v: impl Into<String>) -> Self
pub fn business_connection_id(self, v: impl Into<String>) -> Self
Business connection ID for acting on behalf of a business account.
Sourcepub fn caption_entities(self, v: Vec<MessageEntity>) -> Self
pub fn caption_entities(self, v: Vec<MessageEntity>) -> Self
Special entities in the caption, in place of parse_mode.