GetChatAdministrators

Struct GetChatAdministrators 

pub struct GetChatAdministrators { /* private fields */ }
Builder for the getChatAdministrators method.

Implementations

Source

impl GetChatAdministrators

pub fn return_bots(self, v: bool) -> Self

Pass true to additionally receive all bots that are administrators of the chat. By default, bots other than the current bot are omitted.