pub struct GetChatGifts { /* private fields */ }Expand description
Builder for the getChatGifts method.
Returns the gifts owned by a channel chat.
Implementations
Sourceimpl GetChatGifts
impl GetChatGifts
Sourcepub fn exclude_unsaved(self, v: bool) -> Self
pub fn exclude_unsaved(self, v: bool) -> Self
Excludes gifts not saved to the chat’s profile page.
Sourcepub fn exclude_saved(self, v: bool) -> Self
pub fn exclude_saved(self, v: bool) -> Self
Excludes gifts saved to the chat’s profile page.
Sourcepub fn exclude_unlimited(self, v: bool) -> Self
pub fn exclude_unlimited(self, v: bool) -> Self
Excludes unlimited regular gifts.
Sourcepub fn exclude_limited_upgradable(self, v: bool) -> Self
pub fn exclude_limited_upgradable(self, v: bool) -> Self
Excludes limited gifts that can be upgraded to unique.
Sourcepub fn exclude_limited_non_upgradable(self, v: bool) -> Self
pub fn exclude_limited_non_upgradable(self, v: bool) -> Self
Excludes limited gifts that cannot be upgraded to unique.
Sourcepub fn exclude_unique(self, v: bool) -> Self
pub fn exclude_unique(self, v: bool) -> Self
Excludes unique gifts.
Sourcepub fn exclude_from_blockchain(self, v: bool) -> Self
pub fn exclude_from_blockchain(self, v: bool) -> Self
Excludes gifts assigned from the TON blockchain.
Sourcepub fn sort_by_price(self, v: bool) -> Self
pub fn sort_by_price(self, v: bool) -> Self
Sorts results by price instead of send date.