pub struct UpgradeGift { /* private fields */ }Expand description
Builder for the upgradeGift method.
Upgrades a regular gift to a unique gift.
Requires the can_transfer_and_upgrade_gifts business bot right.
Also requires can_transfer_stars if the upgrade is paid.
Implementations
Sourceimpl UpgradeGift
impl UpgradeGift
Sourcepub fn keep_original_details(self, v: bool) -> Self
pub fn keep_original_details(self, v: bool) -> Self
Pass true to preserve the original gift text, sender, and receiver in the upgraded gift.
Sourcepub fn star_count(self, v: u32) -> Self
pub fn star_count(self, v: u32) -> Self
Stars to pay for the upgrade from the business account balance.
Pass 0 if gift.prepaid_upgrade_star_count > 0.