pub struct AnswerInlineQuery { /* private fields */ }Expand description
Builder for the answerInlineQuery method.
Implementations
Sourceimpl AnswerInlineQuery
impl AnswerInlineQuery
Sourcepub fn cache_time(self, secs: u32) -> Self
pub fn cache_time(self, secs: u32) -> Self
Sets how many seconds the results may be cached on the client (default 300).
Sourcepub fn is_personal(self, v: bool) -> Self
pub fn is_personal(self, v: bool) -> Self
Makes the results personal to the user — disables shared caching.
Sourcepub fn next_offset(self, o: impl Into<String>) -> Self
pub fn next_offset(self, o: impl Into<String>) -> Self
Sets the offset for pagination when there are more results available.
A button shown above the inline query results.