pub struct SavePreparedInlineMessage { /* private fields */ }Expand description
Builder for the savePreparedInlineMessage method.
Stores a message that can be sent by a user from a Mini App. Returns the prepared message.
Implementations
Sourceimpl SavePreparedInlineMessage
impl SavePreparedInlineMessage
Sourcepub fn allow_user_chats(self, v: bool) -> Self
pub fn allow_user_chats(self, v: bool) -> Self
Allows the message to be sent to private chats with users.
Sourcepub fn allow_bot_chats(self, v: bool) -> Self
pub fn allow_bot_chats(self, v: bool) -> Self
Allows the message to be sent to private chats with bots.
Sourcepub fn allow_group_chats(self, v: bool) -> Self
pub fn allow_group_chats(self, v: bool) -> Self
Allows the message to be sent to group and supergroup chats.
Sourcepub fn allow_channel_chats(self, v: bool) -> Self
pub fn allow_channel_chats(self, v: bool) -> Self
Allows the message to be sent to channel chats.