pub struct SetUserEmojiStatus { /* private fields */ }Expand description
Builder for the setUserEmojiStatus method.
Changes the emoji status for a user who previously allowed the bot to manage
their emoji status via the Mini App method requestEmojiStatusAccess.
Omit emoji_status_custom_emoji_id or pass an empty string to remove the status.
Implementations
Sourceimpl SetUserEmojiStatus
impl SetUserEmojiStatus
Sourcepub fn emoji_status_custom_emoji_id(self, id: impl Into<String>) -> Self
pub fn emoji_status_custom_emoji_id(self, id: impl Into<String>) -> Self
Sets the custom emoji identifier for the emoji status. Pass an empty string to remove the current status.
Sourcepub fn emoji_status_expiration_date(self, ts: i64) -> Self
pub fn emoji_status_expiration_date(self, ts: i64) -> Self
Sets the expiration date of the emoji status as a Unix timestamp.