pub struct SetPassportDataErrors { /* private fields */ }Expand description
Builder for the setPassportDataErrors method.
Informs a user that some Telegram Passport elements they provided contain errors. The user will not be able to re-submit their Passport to the bot until the errors are fixed — the contents of the affected field must change.