pub struct SendInvoice { /* private fields */ }Expand description
Builder for the sendInvoice method.
Implementations
Sourceimpl SendInvoice
impl SendInvoice
Sourcepub fn message_thread_id(self, id: i64) -> Self
pub fn message_thread_id(self, id: i64) -> Self
Forum topic thread ID.
Sourcepub fn direct_messages_topic_id(self, id: i64) -> Self
pub fn direct_messages_topic_id(self, id: i64) -> Self
Identifier of a direct messages chat topic.
Sourcepub fn provider_token(self, t: impl Into<String>) -> Self
pub fn provider_token(self, t: impl Into<String>) -> Self
Sets the payment provider token. Not required for Telegram Stars (XTR).
Sourcepub fn need_shipping_address(self, v: bool) -> Self
pub fn need_shipping_address(self, v: bool) -> Self
Requests the buyer’s shipping address during checkout.
Sourcepub fn is_flexible(self, v: bool) -> Self
pub fn is_flexible(self, v: bool) -> Self
Indicates that the final price depends on the shipping method.
Sourcepub fn reply_markup(self, m: InlineKeyboardMarkup) -> Self
pub fn reply_markup(self, m: InlineKeyboardMarkup) -> Self
Attaches a reply markup (inline keyboard, reply keyboard, etc.).
Sourcepub fn suggested_post_parameters(self, params: SuggestedPostParameters) -> Self
pub fn suggested_post_parameters(self, params: SuggestedPostParameters) -> Self
Suggested post parameters for channel direct messages chats.
Sourcepub fn message_effect_id(self, v: impl Into<String>) -> Self
pub fn message_effect_id(self, v: impl Into<String>) -> Self
Attaches a message effect (animated emoji reaction) to the message.
Sourcepub fn max_tip_amount(self, v: u32) -> Self
pub fn max_tip_amount(self, v: u32) -> Self
Sets max_tip_amount.
Sourcepub fn suggested_tip_amounts(self, v: Vec<u32>) -> Self
pub fn suggested_tip_amounts(self, v: Vec<u32>) -> Self
Sets suggested_tip_amounts.
Sourcepub fn start_parameter(self, v: impl Into<String>) -> Self
pub fn start_parameter(self, v: impl Into<String>) -> Self
Sets start_parameter.
Sourcepub fn provider_data(self, v: impl Into<String>) -> Self
pub fn provider_data(self, v: impl Into<String>) -> Self
Sets provider_data.
Sourcepub fn photo_size(self, v: u32) -> Self
pub fn photo_size(self, v: u32) -> Self
Sets photo_size.
Sourcepub fn photo_width(self, v: u32) -> Self
pub fn photo_width(self, v: u32) -> Self
Sets photo_width.
Sourcepub fn photo_height(self, v: u32) -> Self
pub fn photo_height(self, v: u32) -> Self
Sets photo_height.
Sourcepub fn need_phone_number(self, v: bool) -> Self
pub fn need_phone_number(self, v: bool) -> Self
Sets need_phone_number.
Sourcepub fn need_email(self, v: bool) -> Self
pub fn need_email(self, v: bool) -> Self
Sets need_email.
Sourcepub fn send_phone_number_to_provider(self, v: bool) -> Self
pub fn send_phone_number_to_provider(self, v: bool) -> Self
Sets send_phone_number_to_provider.
Sourcepub fn send_email_to_provider(self, v: bool) -> Self
pub fn send_email_to_provider(self, v: bool) -> Self
Sets send_email_to_provider.
Sourcepub fn disable_notification(self, v: bool) -> Self
pub fn disable_notification(self, v: bool) -> Self
Sends the message silently — the recipient receives no notification sound.
Sourcepub fn protect_content(self, v: bool) -> Self
pub fn protect_content(self, v: bool) -> Self
Protects the message from being forwarded or saved.
Sourcepub fn allow_paid_broadcast(self, v: bool) -> Self
pub fn allow_paid_broadcast(self, v: bool) -> Self
Allows sending to large audiences at the cost of Telegram Stars.
Sourcepub fn reply_parameters(self, v: ReplyParameters) -> Self
pub fn reply_parameters(self, v: ReplyParameters) -> Self
Reply parameters for this message.