pub struct AnswerCallbackQuery { /* private fields */ }Expand description
Builder for the answerCallbackQuery method.
Implementations
Sourceimpl AnswerCallbackQuery
impl AnswerCallbackQuery
Sourcepub fn text(self, t: impl Into<String>) -> Self
pub fn text(self, t: impl Into<String>) -> Self
The text of the notification shown to the user. 0–200 characters.
Sourcepub fn show_alert(self, v: bool) -> Self
pub fn show_alert(self, v: bool) -> Self
Shows an alert dialog instead of a toast notification for the callback answer.
Sourcepub fn url(self, u: impl Into<String>) -> Self
pub fn url(self, u: impl Into<String>) -> Self
Sets the URL to open when the callback button answer is tapped.
Sourcepub fn cache_time(self, secs: u32) -> Self
pub fn cache_time(self, secs: u32) -> Self
Sets how long the callback answer may be cached on the client in seconds.