pub struct DeleteEphemeralMessage { /* private fields */ }Expand description
Builder for the deleteEphemeralMessage method.
Note that it is not guaranteed that the user will receive the message deletion event, especially if they are offline.