pub struct SendChecklist { /* private fields */ }Expand description
Builder for the sendChecklist method.
Business bots only — sends a checklist on behalf of a connected business account.
Requires the can_reply business bot right.
Implementations
Sourceimpl SendChecklist
impl SendChecklist
Sourcepub fn direct_messages_topic_id(self, id: i64) -> Self
pub fn direct_messages_topic_id(self, id: i64) -> Self
Identifier of a direct messages chat topic.
Sourcepub fn disable_notification(self, v: bool) -> Self
pub fn disable_notification(self, v: bool) -> Self
Sends the message silently — the recipient receives no notification sound.
Sourcepub fn protect_content(self, v: bool) -> Self
pub fn protect_content(self, v: bool) -> Self
Protects the message from being forwarded or saved.
Sourcepub fn message_effect_id(self, id: impl Into<String>) -> Self
pub fn message_effect_id(self, id: impl Into<String>) -> Self
Unique identifier of the message effect to add to the message.
Sourcepub fn reply_parameters(self, rp: ReplyParameters) -> Self
pub fn reply_parameters(self, rp: ReplyParameters) -> Self
Reply parameters for this message.
Sourcepub fn reply_markup(self, m: InlineKeyboardMarkup) -> Self
pub fn reply_markup(self, m: InlineKeyboardMarkup) -> Self
Attaches an inline keyboard to the message.
Sourcepub fn suggested_post_parameters(self, params: SuggestedPostParameters) -> Self
pub fn suggested_post_parameters(self, params: SuggestedPostParameters) -> Self
Suggested post parameters for channel direct messages chats.