pub struct SendDice { /* private fields */ }Expand description
Builder for the sendDice method.
Implementations
Sourceimpl SendDice
impl SendDice
Sourcepub fn emoji(self, e: impl Into<String>) -> Self
pub fn emoji(self, e: impl Into<String>) -> Self
The dice/emoji to animate. One of 🎲 🎯 🏀 ⚽ 🎳 🎰.
Sourcepub fn message_thread_id(self, id: i64) -> Self
pub fn message_thread_id(self, id: i64) -> Self
Forum topic thread ID.
Sourcepub fn direct_messages_topic_id(self, id: i64) -> Self
pub fn direct_messages_topic_id(self, id: i64) -> Self
Identifier of a direct messages chat topic.
Sourcepub fn disable_notification(self, v: bool) -> Self
pub fn disable_notification(self, v: bool) -> Self
Sends the message silently — the recipient receives no notification sound.
Sourcepub fn reply_markup(self, m: impl Into<ReplyMarkup>) -> Self
pub fn reply_markup(self, m: impl Into<ReplyMarkup>) -> Self
Attaches a reply markup (inline keyboard, reply keyboard, etc.).
Sourcepub fn business_connection_id(self, v: impl Into<String>) -> Self
pub fn business_connection_id(self, v: impl Into<String>) -> Self
Business connection ID for acting on behalf of a business account.
Sourcepub fn allow_paid_broadcast(self, v: bool) -> Self
pub fn allow_paid_broadcast(self, v: bool) -> Self
Allows sending to large audiences at the cost of Telegram Stars.
Sourcepub fn message_effect_id(self, v: impl Into<String>) -> Self
pub fn message_effect_id(self, v: impl Into<String>) -> Self
Attaches a message effect (animated emoji reaction) to the message.
Sourcepub fn suggested_post_parameters(self, v: SuggestedPostParameters) -> Self
pub fn suggested_post_parameters(self, v: SuggestedPostParameters) -> Self
Suggested post parameters for channel direct messages chats.
Sourcepub fn protect_content(self, v: bool) -> Self
pub fn protect_content(self, v: bool) -> Self
Protects the message from being forwarded or saved.
Sourcepub fn reply_parameters(self, v: ReplyParameters) -> Self
pub fn reply_parameters(self, v: ReplyParameters) -> Self
Reply parameters for this message.