pub struct SendLivePhoto { /* private fields */ }Expand description
Builder for the sendLivePhoto method.
Implementations
Sourceimpl SendLivePhoto
impl SendLivePhoto
Sourcepub fn business_connection_id(self, id: impl Into<String>) -> Self
pub fn business_connection_id(self, id: impl Into<String>) -> Self
Business connection ID for sending on behalf of a business account.
Sourcepub fn message_thread_id(self, id: i64) -> Self
pub fn message_thread_id(self, id: i64) -> Self
Forum topic thread ID.
Sourcepub fn direct_messages_topic_id(self, id: i64) -> Self
pub fn direct_messages_topic_id(self, id: i64) -> Self
Identifier of a direct messages chat topic.
Sourcepub fn parse_mode(self, m: ParseMode) -> Self
pub fn parse_mode(self, m: ParseMode) -> Self
Sets the caption parse mode.
Sourcepub fn show_caption_above_media(self, v: bool) -> Self
pub fn show_caption_above_media(self, v: bool) -> Self
Shows the caption above the media instead of below it.
Sourcepub fn has_spoiler(self, v: bool) -> Self
pub fn has_spoiler(self, v: bool) -> Self
Covers the live photo with a spoiler animation.
Sourcepub fn disable_notification(self, v: bool) -> Self
pub fn disable_notification(self, v: bool) -> Self
Sends the message silently.
Sourcepub fn protect_content(self, v: bool) -> Self
pub fn protect_content(self, v: bool) -> Self
Protects the message from being forwarded or saved.
Sourcepub fn allow_paid_broadcast(self, v: bool) -> Self
pub fn allow_paid_broadcast(self, v: bool) -> Self
Allows sending to large audiences at the cost of Telegram Stars.
Sourcepub fn message_effect_id(self, id: impl Into<String>) -> Self
pub fn message_effect_id(self, id: impl Into<String>) -> Self
Attaches a message effect (private chats only).
Sourcepub fn reply_parameters(self, rp: ReplyParameters) -> Self
pub fn reply_parameters(self, rp: ReplyParameters) -> Self
Reply parameters for this message.
Sourcepub fn reply_markup(self, m: impl Into<ReplyMarkup>) -> Self
pub fn reply_markup(self, m: impl Into<ReplyMarkup>) -> Self
Attaches a reply markup.
Sourcepub fn suggested_post_parameters(self, params: SuggestedPostParameters) -> Self
pub fn suggested_post_parameters(self, params: SuggestedPostParameters) -> Self
Suggested post parameters for channel direct messages chats.