pub struct SendMediaGroup { /* private fields */ }Expand description
Builder for the sendMediaGroup method.
Sends a group of photos, videos, documents, or audios as an album (2–10 items).
Implementations
Sourceimpl SendMediaGroup
impl SendMediaGroup
Sourcepub fn message_thread_id(self, id: i64) -> Self
pub fn message_thread_id(self, id: i64) -> Self
Forum topic thread ID.
Sourcepub fn direct_messages_topic_id(self, id: i64) -> Self
pub fn direct_messages_topic_id(self, id: i64) -> Self
Identifier of a direct messages chat topic.
Sourcepub fn business_connection_id(self, id: impl Into<String>) -> Self
pub fn business_connection_id(self, id: impl Into<String>) -> Self
Business connection ID for sending on behalf of a business account.
Sourcepub fn disable_notification(self, v: bool) -> Self
pub fn disable_notification(self, v: bool) -> Self
Sends the messages silently — recipients receive no notification sound.
Sourcepub fn protect_content(self, v: bool) -> Self
pub fn protect_content(self, v: bool) -> Self
Protects the messages from being forwarded or saved.
Sourcepub fn reply_parameters(self, rp: ReplyParameters) -> Self
pub fn reply_parameters(self, rp: ReplyParameters) -> Self
Reply parameters for this message.
Sourcepub fn allow_paid_broadcast(self, v: bool) -> Self
pub fn allow_paid_broadcast(self, v: bool) -> Self
Allows sending to large audiences at the cost of Telegram Stars.
Sourcepub fn message_effect_id(self, v: impl Into<String>) -> Self
pub fn message_effect_id(self, v: impl Into<String>) -> Self
Attaches a message effect (animated emoji reaction) to the message.