pub struct SendMessageDraft { /* private fields */ }Expand description
Builder for the sendMessageDraft method.
Streams a partial message to the user while it is being generated (Bot API 9.5+).
Implementations
Sourceimpl SendMessageDraft
impl SendMessageDraft
Sourcepub fn parse_mode(self, m: ParseMode) -> Self
pub fn parse_mode(self, m: ParseMode) -> Self
Sets the text parse mode (MarkdownV2, HTML, or Markdown).
Sourcepub fn entities(self, e: Vec<MessageEntity>) -> Self
pub fn entities(self, e: Vec<MessageEntity>) -> Self
Sets custom message entities instead of using a parse mode.
Sourcepub fn clear_text(self) -> Self
pub fn clear_text(self) -> Self
Sends the draft with no text at all, which the API permits.
Sourcepub fn message_thread_id(self, v: i64) -> Self
pub fn message_thread_id(self, v: i64) -> Self
Forum topic thread ID.