pub struct SendRichMessage { /* private fields */ }Expand description
Builder for the sendRichMessage method.
Implementations
Sourceimpl SendRichMessage
impl SendRichMessage
Sourcepub fn business_connection_id(self, id: impl Into<String>) -> Self
pub fn business_connection_id(self, id: impl Into<String>) -> Self
Sets the business connection identifier.
Sourcepub fn message_thread_id(self, id: i64) -> Self
pub fn message_thread_id(self, id: i64) -> Self
Sends the message to the specified topic thread.
Sourcepub fn direct_messages_topic_id(self, id: i64) -> Self
pub fn direct_messages_topic_id(self, id: i64) -> Self
Sends the message to the specified direct messages topic.
Sourcepub fn disable_notification(self, v: bool) -> Self
pub fn disable_notification(self, v: bool) -> Self
Sends the message silently (no notification sound).
Sourcepub fn protect_content(self, v: bool) -> Self
pub fn protect_content(self, v: bool) -> Self
Protects the message from being forwarded or saved.
Sourcepub fn allow_paid_broadcast(self, v: bool) -> Self
pub fn allow_paid_broadcast(self, v: bool) -> Self
Allows up to 1 000 messages per second by paying 0.1 Stars per message.
Sourcepub fn message_effect_id(self, id: impl Into<String>) -> Self
pub fn message_effect_id(self, id: impl Into<String>) -> Self
Unique identifier of the message effect to add to the message.
Sourcepub fn suggested_post_parameters(self, p: SuggestedPostParameters) -> Self
pub fn suggested_post_parameters(self, p: SuggestedPostParameters) -> Self
Suggested post parameters for channel direct messages chats.
Sourcepub fn reply_parameters(self, rp: ReplyParameters) -> Self
pub fn reply_parameters(self, rp: ReplyParameters) -> Self
Reply parameters for this message.
Sourcepub fn reply_markup(self, m: ReplyMarkup) -> Self
pub fn reply_markup(self, m: ReplyMarkup) -> Self
Attaches a reply markup to the message.