pub struct SendVideoNote { /* private fields */ }Expand description
Builder for the sendVideoNote method.
Implementations
Sourceimpl SendVideoNote
impl SendVideoNote
Sourcepub fn business_connection_id(self, id: impl Into<String>) -> Self
pub fn business_connection_id(self, id: impl Into<String>) -> Self
Business connection ID for sending on behalf of a business account.
Sourcepub fn message_thread_id(self, id: i64) -> Self
pub fn message_thread_id(self, id: i64) -> Self
Forum topic thread ID.
Sourcepub fn direct_messages_topic_id(self, id: i64) -> Self
pub fn direct_messages_topic_id(self, id: i64) -> Self
Identifier of a direct messages chat topic.
Sourcepub fn disable_notification(self, v: bool) -> Self
pub fn disable_notification(self, v: bool) -> Self
Sends the message silently — the recipient receives no notification sound.
Sourcepub fn message_effect_id(self, id: impl Into<String>) -> Self
pub fn message_effect_id(self, id: impl Into<String>) -> Self
Attaches a message effect (animated emoji reaction) to the message.
Sourcepub fn protect_content(self, v: bool) -> Self
pub fn protect_content(self, v: bool) -> Self
Protects the message from being forwarded or saved.
Sourcepub fn allow_paid_broadcast(self, v: bool) -> Self
pub fn allow_paid_broadcast(self, v: bool) -> Self
Allows sending to large audiences at the cost of Telegram Stars.
Sourcepub fn reply_parameters(self, rp: ReplyParameters) -> Self
pub fn reply_parameters(self, rp: ReplyParameters) -> Self
Reply parameters for this message.
Sourcepub fn reply_markup(self, m: impl Into<ReplyMarkup>) -> Self
pub fn reply_markup(self, m: impl Into<ReplyMarkup>) -> Self
Attaches a reply markup (inline keyboard, reply keyboard, etc.).
Sourcepub fn suggested_post_parameters(self, params: SuggestedPostParameters) -> Self
pub fn suggested_post_parameters(self, params: SuggestedPostParameters) -> Self
Suggested post parameters for channel direct messages chats.
Sourcepub fn receiver_user_id(self, id: i64) -> Self
pub fn receiver_user_id(self, id: i64) -> Self
For outgoing ephemeral messages — the user who will receive the message.
Sourcepub fn callback_query_id(self, id: impl Into<String>) -> Self
pub fn callback_query_id(self, id: impl Into<String>) -> Self
For outgoing ephemeral messages — the callback query that triggered it, if any.