pub struct SendVoice { /* private fields */ }Expand description
Builder for the sendVoice method.
Implementations
Sourceimpl SendVoice
impl SendVoice
Sourcepub fn business_connection_id(self, id: impl Into<String>) -> Self
pub fn business_connection_id(self, id: impl Into<String>) -> Self
Business connection ID for sending on behalf of a business account.
Sourcepub fn message_thread_id(self, id: i64) -> Self
pub fn message_thread_id(self, id: i64) -> Self
Forum topic thread ID.
Sourcepub fn direct_messages_topic_id(self, id: i64) -> Self
pub fn direct_messages_topic_id(self, id: i64) -> Self
Identifier of a direct messages chat topic.
Sourcepub fn caption(self, c: impl Into<String>) -> Self
pub fn caption(self, c: impl Into<String>) -> Self
Sets the caption (0–1024 characters) for media messages.
Sourcepub fn parse_mode(self, m: ParseMode) -> Self
pub fn parse_mode(self, m: ParseMode) -> Self
Sets the caption parse mode (MarkdownV2, HTML, or Markdown).
Sourcepub fn disable_notification(self, v: bool) -> Self
pub fn disable_notification(self, v: bool) -> Self
Sends the message silently — the recipient receives no notification sound.
Sourcepub fn protect_content(self, v: bool) -> Self
pub fn protect_content(self, v: bool) -> Self
Protects the message from being forwarded or saved.
Sourcepub fn allow_paid_broadcast(self, v: bool) -> Self
pub fn allow_paid_broadcast(self, v: bool) -> Self
Allows sending to large audiences at the cost of Telegram Stars.
Sourcepub fn reply_parameters(self, rp: ReplyParameters) -> Self
pub fn reply_parameters(self, rp: ReplyParameters) -> Self
Reply parameters for this message.
Sourcepub fn reply_markup(self, m: impl Into<ReplyMarkup>) -> Self
pub fn reply_markup(self, m: impl Into<ReplyMarkup>) -> Self
Attaches a reply markup (inline keyboard, reply keyboard, etc.).
Sourcepub fn suggested_post_parameters(self, params: SuggestedPostParameters) -> Self
pub fn suggested_post_parameters(self, params: SuggestedPostParameters) -> Self
Suggested post parameters for channel direct messages chats.