pub struct SetCustomEmojiStickerSetThumbnail { /* private fields */ }Expand description
Builder for the setCustomEmojiStickerSetThumbnail method.
Sets the thumbnail of a custom emoji sticker set.
Omit custom_emoji_id or pass an empty string to drop the current thumbnail
and use the first sticker instead.
Implementations
Sourceimpl SetCustomEmojiStickerSetThumbnail
impl SetCustomEmojiStickerSetThumbnail
Sourcepub fn custom_emoji_id(self, id: impl Into<String>) -> Self
pub fn custom_emoji_id(self, id: impl Into<String>) -> Self
Sets the custom emoji identifier to use as the thumbnail. Pass an empty string to remove the current thumbnail.