SetStickerSetThumbnail

Struct SetStickerSetThumbnail 

pub struct SetStickerSetThumbnail { /* private fields */ }
Builder for the setStickerSetThumbnail method.

Sets the thumbnail of a regular or mask sticker set. The thumbnail format must match the sticker format in the set. Omit thumbnail to drop the current thumbnail and use the first sticker instead.

Implementations

Source

impl SetStickerSetThumbnail

pub fn thumbnail(self, f: InputFile) -> Self

Sets the thumbnail file to upload. Omit to remove the current thumbnail.