pub struct Close { /* private fields */ }Expand description
Builder for the close method.
Closes the bot instance before moving it to another local server. Delete the webhook before calling this to prevent the bot from restarting. Returns error 429 in the first 10 minutes after launch.