pub struct PromoteChatMember { /* private fields */ }Expand description
Builder for the promoteChatMember method.
Implementations
Sourceimpl PromoteChatMember
impl PromoteChatMember
Sourcepub fn can_manage_chat(self, v: bool) -> Self
pub fn can_manage_chat(self, v: bool) -> Self
Allows the admin to manage the chat.
Sourcepub fn can_delete_messages(self, v: bool) -> Self
pub fn can_delete_messages(self, v: bool) -> Self
Allows the admin to delete messages of other users.
Sourcepub fn can_manage_video_chats(self, v: bool) -> Self
pub fn can_manage_video_chats(self, v: bool) -> Self
Allows the admin to manage video chats.
Sourcepub fn can_restrict_members(self, v: bool) -> Self
pub fn can_restrict_members(self, v: bool) -> Self
Allows the admin to restrict, ban, or unban chat members.
Sourcepub fn can_promote_members(self, v: bool) -> Self
pub fn can_promote_members(self, v: bool) -> Self
Allows the admin to add new administrators with a subset of their own privileges or demote administrators that they have promoted, directly or indirectly (promoted by administrators that were appointed by the user).
Sourcepub fn can_change_info(self, v: bool) -> Self
pub fn can_change_info(self, v: bool) -> Self
Allows the admin to change the chat title, photo, and other settings.
Sourcepub fn can_invite_users(self, v: bool) -> Self
pub fn can_invite_users(self, v: bool) -> Self
Allows the admin to invite new users to the chat.
Sourcepub fn can_pin_messages(self, v: bool) -> Self
pub fn can_pin_messages(self, v: bool) -> Self
Allows the admin to pin messages.
Sourcepub fn can_manage_topics(self, v: bool) -> Self
pub fn can_manage_topics(self, v: bool) -> Self
Allows the admin to manage forum topics.
Sourcepub fn can_post_stories(self, v: bool) -> Self
pub fn can_post_stories(self, v: bool) -> Self
Allows the admin to post stories.
Sourcepub fn can_manage_direct_messages(self, v: bool) -> Self
pub fn can_manage_direct_messages(self, v: bool) -> Self
Allows the admin to manage direct messages.
Allows the admin to manage tags.