pub struct EditEphemeralMessageText { /* private fields */ }Expand description
Builder for the editEphemeralMessageText method.
Note that it is not guaranteed that the user will receive the message edit event, especially if they are offline.
Implementations
Sourceimpl EditEphemeralMessageText
impl EditEphemeralMessageText
Sourcepub fn parse_mode(self, m: ParseMode) -> Self
pub fn parse_mode(self, m: ParseMode) -> Self
Sets the parse mode for the message text.
Sourcepub fn entities(self, e: Vec<MessageEntity>) -> Self
pub fn entities(self, e: Vec<MessageEntity>) -> Self
Special entities in the message text, in place of parse_mode.
Sourcepub fn reply_markup(self, m: InlineKeyboardMarkup) -> Self
pub fn reply_markup(self, m: InlineKeyboardMarkup) -> Self
Attaches a reply markup (inline keyboard, reply keyboard, etc.).
Sourcepub fn link_preview_options(self, v: LinkPreviewOptions) -> Self
pub fn link_preview_options(self, v: LinkPreviewOptions) -> Self
Configures link preview generation options.