pub struct SetGameScore { /* private fields */ }Expand description
Builder for the setGameScore method.
Sets the score for a user in a game. Returns the edited Message on success
for chat messages, or true for inline messages.
Returns an error if the new score is not greater than the user’s current score
and force is not set.
Implementations
Sourceimpl SetGameScore
impl SetGameScore
Sourcepub fn force(self, v: bool) -> Self
pub fn force(self, v: bool) -> Self
Pass true to allow the score to decrease — useful for fixing mistakes or banning cheaters.
Sourcepub fn disable_edit_message(self, v: bool) -> Self
pub fn disable_edit_message(self, v: bool) -> Self
Pass true to prevent the game message from being edited with the new scoreboard.
Sourcepub fn chat_message(self, chat_id: i64, message_id: i64) -> Self
pub fn chat_message(self, chat_id: i64, message_id: i64) -> Self
Sets the target chat message. Required if inline_message_id is not set.
Sourcepub fn inline_message_id(self, id: impl Into<String>) -> Self
pub fn inline_message_id(self, id: impl Into<String>) -> Self
Sets the target inline message. Required if chat_id and message_id are not set.