pub struct GetChatAdministrators { /* private fields */ }Expand description
Builder for the getChatAdministrators method.
Implementations
Sourceimpl GetChatAdministrators
impl GetChatAdministrators
Sourcepub fn return_bots(self, v: bool) -> Self
pub fn return_bots(self, v: bool) -> Self
Pass true to additionally receive all bots that are administrators of the chat.
By default, bots other than the current bot are omitted.