pub struct AnswerWebAppQuery { /* private fields */ }Expand description
Builder for the answerWebAppQuery method.
Sets the result of an interaction with a Web App and sends the corresponding
message on behalf of the user to the originating chat.
Returns a SentWebAppMessage object.