CreateInvoiceLink

Struct CreateInvoiceLink 

pub struct CreateInvoiceLink { /* private fields */ }
Builder for the createInvoiceLink method.

Creates a shareable payment link. Returns the link as a String.

Implementations

pub fn business_connection_id(self, id: impl Into<String>) -> Self

Business connection ID; for Telegram Stars payments only.

pub fn provider_token(self, t: impl Into<String>) -> Self

Sets the payment provider token. Not required for Telegram Stars (XTR).

pub fn subscription_period(self, secs: i64) -> Self

The number of seconds the subscription will be active before the next payment. Currently must always be 2592000 (30 days) if specified.

pub fn max_tip_amount(self, v: i64) -> Self

Sets the maximum accepted tip amount in the smallest currency units.

pub fn photo_url(self, url: impl Into<String>) -> Self

Sets the URL of the product photo.

pub fn need_name(self, v: bool) -> Self

Requests the buyer’s full name during checkout.

pub fn need_phone_number(self, v: bool) -> Self

Requests the buyer’s phone number during checkout.

pub fn need_email(self, v: bool) -> Self

Requests the buyer’s email address during checkout.

pub fn need_shipping_address(self, v: bool) -> Self

Requests the buyer’s shipping address during checkout.

pub fn send_phone_number_to_provider(self, v: bool) -> Self

Forwards the buyer’s phone number to the provider.

pub fn send_email_to_provider(self, v: bool) -> Self

Forwards the buyer’s email address to the provider.

pub fn is_flexible(self, v: bool) -> Self

Indicates that the final price depends on the shipping method.

pub fn suggested_tip_amounts(self, v: Vec<i64>) -> Self

Sets suggested_tip_amounts.

pub fn provider_data(self, v: impl Into<String>) -> Self

Sets provider_data.

pub fn photo_size(self, v: i64) -> Self

Sets photo_size.

pub fn photo_width(self, v: i64) -> Self

Sets photo_width.

pub fn photo_height(self, v: i64) -> Self

Sets photo_height.