pub struct CreateInvoiceLink { /* private fields */ }Expand description
Builder for the createInvoiceLink method.
Creates a shareable payment link. Returns the link as a String.
Implementations
Sourceimpl CreateInvoiceLink
impl CreateInvoiceLink
Sourcepub fn business_connection_id(self, id: impl Into<String>) -> Self
pub fn business_connection_id(self, id: impl Into<String>) -> Self
Business connection ID; for Telegram Stars payments only.
Sourcepub fn provider_token(self, t: impl Into<String>) -> Self
pub fn provider_token(self, t: impl Into<String>) -> Self
Sets the payment provider token. Not required for Telegram Stars (XTR).
Sourcepub fn subscription_period(self, secs: i64) -> Self
pub fn subscription_period(self, secs: i64) -> Self
The number of seconds the subscription will be active before the next payment.
Currently must always be 2592000 (30 days) if specified.
Sourcepub fn max_tip_amount(self, v: i64) -> Self
pub fn max_tip_amount(self, v: i64) -> Self
Sets the maximum accepted tip amount in the smallest currency units.
Sourcepub fn need_phone_number(self, v: bool) -> Self
pub fn need_phone_number(self, v: bool) -> Self
Requests the buyer’s phone number during checkout.
Sourcepub fn need_email(self, v: bool) -> Self
pub fn need_email(self, v: bool) -> Self
Requests the buyer’s email address during checkout.
Sourcepub fn need_shipping_address(self, v: bool) -> Self
pub fn need_shipping_address(self, v: bool) -> Self
Requests the buyer’s shipping address during checkout.
Sourcepub fn send_phone_number_to_provider(self, v: bool) -> Self
pub fn send_phone_number_to_provider(self, v: bool) -> Self
Forwards the buyer’s phone number to the provider.
Sourcepub fn send_email_to_provider(self, v: bool) -> Self
pub fn send_email_to_provider(self, v: bool) -> Self
Forwards the buyer’s email address to the provider.
Sourcepub fn is_flexible(self, v: bool) -> Self
pub fn is_flexible(self, v: bool) -> Self
Indicates that the final price depends on the shipping method.
Sourcepub fn suggested_tip_amounts(self, v: Vec<i64>) -> Self
pub fn suggested_tip_amounts(self, v: Vec<i64>) -> Self
Sets suggested_tip_amounts.
Sourcepub fn provider_data(self, v: impl Into<String>) -> Self
pub fn provider_data(self, v: impl Into<String>) -> Self
Sets provider_data.
Sourcepub fn photo_size(self, v: i64) -> Self
pub fn photo_size(self, v: i64) -> Self
Sets photo_size.
Sourcepub fn photo_width(self, v: i64) -> Self
pub fn photo_width(self, v: i64) -> Self
Sets photo_width.
Sourcepub fn photo_height(self, v: i64) -> Self
pub fn photo_height(self, v: i64) -> Self
Sets photo_height.