Message and media sending methods.
Structs
- Answer
Callback Query - Builder for the
answerCallbackQuerymethod. - Copy
Message - Builder for the
copyMessagemethod. - Copy
Messages - Builder for the
copyMessagesmethod. - Delete
Message - Builder for the
deleteMessagemethod. - Delete
Messages - Builder for the
deleteMessagesmethod. - Forward
Message - Builder for the
forwardMessagemethod. - Forward
Messages - Builder for the
forwardMessagesmethod. - Media
Send Options - Common optional parameters shared by most media-send methods.
- Send
Animation - Builder for the
sendAnimationmethod. - Send
Audio - Builder for the
sendAudiomethod. - Send
Chat Action - Builder for the
sendChatActionmethod. - Send
Checklist - Builder for the
sendChecklistmethod. - Send
Contact - Builder for the
sendContactmethod. - Send
Dice - Builder for the
sendDicemethod. - Send
Document - Builder for the
sendDocumentmethod. - Send
Game - Builder for the
sendGamemethod. - Send
Live Photo - Builder for the
sendLivePhotomethod. - Send
Location - Builder for the
sendLocationmethod. - Send
Media Group - Builder for the
sendMediaGroupmethod. - Send
Message - Builder for the
sendMessagemethod. - Send
Message Draft - Builder for the
sendMessageDraftmethod. Streams a partial message to the user while it is being generated (Bot API 9.5+). - Send
Paid Media - Builder for the
sendPaidMediamethod. - Send
Photo - Builder for the
sendPhotomethod. - Send
Poll - Builder for the
sendPollmethod. - Send
Sticker - Builder for the
sendStickermethod. - Send
Venue - Builder for the
sendVenuemethod. - Send
Video - Builder for the
sendVideomethod. - Send
Video Note - Builder for the
sendVideoNotemethod. - Send
Voice - Builder for the
sendVoicemethod. - Stop
Poll - Builder for the
stopPollmethod.
Enums
- Chat
Action - The chat action to display while the bot is preparing a response.