Module sending

Module sending 

Message and media sending methods.

Structs

AnswerCallbackQuery
Builder for the answerCallbackQuery method.
CopyMessage
Builder for the copyMessage method.
DeleteMessage
Builder for the deleteMessage method.
DeleteMessages
Builder for the deleteMessages method.
ForwardMessage
Builder for the forwardMessage method.
MediaSendOptions
Common optional parameters shared by most media-send methods.
SendAnimation
Builder for the sendAnimation method.
SendAudio
Builder for the sendAudio method.
SendChatAction
Builder for the sendChatAction method.
SendContact
Builder for the sendContact method.
SendDice
Builder for the sendDice method.
SendDocument
Builder for the sendDocument method.
SendLocation
Builder for the sendLocation method.
SendMessage
Builder for the sendMessage method.
SendMessageDraft
Builder for the sendMessageDraft method. Streams a partial message to the user while it is being generated (Bot API 9.5+).
SendPhoto
Builder for the sendPhoto method.
SendPoll
Builder for the sendPoll method.
SendSticker
Builder for the sendSticker method.
SendVideo
Builder for the sendVideo method.
SendVideoNote
Builder for the sendVideoNote method.
SendVoice
Builder for the sendVoice method.
StopPoll
Builder for the stopPoll method.

Enums

ChatAction
The chat action to display while the bot is preparing a response.