pub struct SetStickerSetThumbnail { /* private fields */ }Expand description
Builder for the setStickerSetThumbnail method.
Sets the thumbnail of a regular or mask sticker set.
The thumbnail format must match the sticker format in the set.
Omit thumbnail to drop the current thumbnail and use the first sticker instead.
Implementations